pub enum DebugRequest {
LogStackTrace {
node_token: Event,
responder: DebugLogStackTraceResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: DebugControlHandle,
method_type: MethodType,
},
}Expand description
Requests to output driver info to persistent logs.
Variants
LogStackTrace
Triggers a log of a full stack trace for the host corresponding to
a node uniquely identified by node_token.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: DebugControlHandle
method_type: MethodTypeImplementations
Sourceimpl DebugRequest
impl DebugRequest
pub fn into_log_stack_trace( self, ) -> Option<(Event, DebugLogStackTraceResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL