pub struct DebugGetHostKoidRequest {
pub node_token: Event,
}Fields
node_token: EventTrait Implementations
Sourceimpl Debug for DebugGetHostKoidRequest
impl Debug for DebugGetHostKoidRequest
Sourceimpl Decode<DebugGetHostKoidRequest, DefaultFuchsiaResourceDialect> for DebugGetHostKoidRequest
impl Decode<DebugGetHostKoidRequest, DefaultFuchsiaResourceDialect> for DebugGetHostKoidRequest
Sourceimpl Encode<DebugGetHostKoidRequest, DefaultFuchsiaResourceDialect> for &mut DebugGetHostKoidRequest
impl Encode<DebugGetHostKoidRequest, DefaultFuchsiaResourceDialect> for &mut DebugGetHostKoidRequest
Sourceimpl<T0: Encode<HandleType<Event, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<DebugGetHostKoidRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<HandleType<Event, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<DebugGetHostKoidRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Hash for DebugGetHostKoidRequest
impl Hash for DebugGetHostKoidRequest
Sourceimpl Ord for DebugGetHostKoidRequest
impl Ord for DebugGetHostKoidRequest
Sourcefn cmp(&self, other: &DebugGetHostKoidRequest) -> Ordering
fn cmp(&self, other: &DebugGetHostKoidRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DebugGetHostKoidRequest
impl PartialEq for DebugGetHostKoidRequest
Sourceimpl PartialOrd for DebugGetHostKoidRequest
impl PartialOrd for DebugGetHostKoidRequest
Sourceimpl ResourceTypeMarker for DebugGetHostKoidRequest
impl ResourceTypeMarker for DebugGetHostKoidRequest
Sourcetype Borrowed<'a> = &'a mut DebugGetHostKoidRequest
type Borrowed<'a> = &'a mut DebugGetHostKoidRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for DebugGetHostKoidRequest
impl TypeMarker for DebugGetHostKoidRequest
Sourcetype Owned = DebugGetHostKoidRequest
type Owned = DebugGetHostKoidRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for DebugGetHostKoidRequest
impl Standalone<DefaultFuchsiaResourceDialect> for DebugGetHostKoidRequest
impl StructuralPartialEq for DebugGetHostKoidRequest