#[repr(C)]pub struct DebugGetHostKoidResponse {
pub host_koid: u64,
}Fields
host_koid: u64Trait Implementations
Sourceimpl Clone for DebugGetHostKoidResponse
impl Clone for DebugGetHostKoidResponse
Sourcefn clone(&self) -> DebugGetHostKoidResponse
fn clone(&self) -> DebugGetHostKoidResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DebugGetHostKoidResponse
impl Debug for DebugGetHostKoidResponse
Sourceimpl<D> Decode<DebugGetHostKoidResponse, D> for DebugGetHostKoidResponsewhere
D: ResourceDialect,
impl<D> Decode<DebugGetHostKoidResponse, D> for DebugGetHostKoidResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> DebugGetHostKoidResponse
fn new_empty() -> DebugGetHostKoidResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DebugGetHostKoidResponse, D> for &DebugGetHostKoidResponsewhere
D: ResourceDialect,
impl<D> Encode<DebugGetHostKoidResponse, D> for &DebugGetHostKoidResponsewhere
D: ResourceDialect,
Sourceimpl Hash for DebugGetHostKoidResponse
impl Hash for DebugGetHostKoidResponse
Sourceimpl Ord for DebugGetHostKoidResponse
impl Ord for DebugGetHostKoidResponse
Sourcefn cmp(&self, other: &DebugGetHostKoidResponse) -> Ordering
fn cmp(&self, other: &DebugGetHostKoidResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DebugGetHostKoidResponse
impl PartialEq for DebugGetHostKoidResponse
Sourceimpl PartialOrd for DebugGetHostKoidResponse
impl PartialOrd for DebugGetHostKoidResponse
Sourceimpl TypeMarker for DebugGetHostKoidResponse
impl TypeMarker for DebugGetHostKoidResponse
Sourcetype Owned = DebugGetHostKoidResponse
type Owned = DebugGetHostKoidResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DebugGetHostKoidResponse
impl ValueTypeMarker for DebugGetHostKoidResponse
Sourcetype Borrowed<'a> = &'a DebugGetHostKoidResponse
type Borrowed<'a> = &'a DebugGetHostKoidResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DebugGetHostKoidResponse as TypeMarker>::Owned,
) -> <DebugGetHostKoidResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DebugGetHostKoidResponse as TypeMarker>::Owned, ) -> <DebugGetHostKoidResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for DebugGetHostKoidResponse
impl Eq for DebugGetHostKoidResponse
impl Persistable for DebugGetHostKoidResponse
impl StructuralPartialEq for DebugGetHostKoidResponse