pub struct DebugLogStackTraceRequest {
pub node_token: Event,
}Fields
node_token: EventTrait Implementations
Sourceimpl Debug for DebugLogStackTraceRequest
impl Debug for DebugLogStackTraceRequest
Sourceimpl Decode<DebugLogStackTraceRequest, DefaultFuchsiaResourceDialect> for DebugLogStackTraceRequest
impl Decode<DebugLogStackTraceRequest, DefaultFuchsiaResourceDialect> for DebugLogStackTraceRequest
Sourceimpl Encode<DebugLogStackTraceRequest, DefaultFuchsiaResourceDialect> for &mut DebugLogStackTraceRequest
impl Encode<DebugLogStackTraceRequest, DefaultFuchsiaResourceDialect> for &mut DebugLogStackTraceRequest
Sourceimpl<T0: Encode<HandleType<Event, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<DebugLogStackTraceRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<HandleType<Event, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<DebugLogStackTraceRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Hash for DebugLogStackTraceRequest
impl Hash for DebugLogStackTraceRequest
Sourceimpl Ord for DebugLogStackTraceRequest
impl Ord for DebugLogStackTraceRequest
Sourcefn cmp(&self, other: &DebugLogStackTraceRequest) -> Ordering
fn cmp(&self, other: &DebugLogStackTraceRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for DebugLogStackTraceRequest
impl PartialOrd for DebugLogStackTraceRequest
Sourceimpl ResourceTypeMarker for DebugLogStackTraceRequest
impl ResourceTypeMarker for DebugLogStackTraceRequest
Sourcetype Borrowed<'a> = &'a mut DebugLogStackTraceRequest
type Borrowed<'a> = &'a mut DebugLogStackTraceRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for DebugLogStackTraceRequest
impl TypeMarker for DebugLogStackTraceRequest
Sourcetype Owned = DebugLogStackTraceRequest
type Owned = DebugLogStackTraceRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for DebugLogStackTraceRequest
impl Standalone<DefaultFuchsiaResourceDialect> for DebugLogStackTraceRequest
impl StructuralPartialEq for DebugLogStackTraceRequest