pub struct NodeBusTopologyMarker;Trait Implementations
Sourceimpl Clone for NodeBusTopologyMarker
impl Clone for NodeBusTopologyMarker
Sourcefn clone(&self) -> NodeBusTopologyMarker
fn clone(&self) -> NodeBusTopologyMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeBusTopologyMarker
impl Debug for NodeBusTopologyMarker
Sourceimpl DiscoverableProtocolMarker for NodeBusTopologyMarker
impl DiscoverableProtocolMarker for NodeBusTopologyMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for NodeBusTopologyMarker
impl Hash for NodeBusTopologyMarker
Sourceimpl Ord for NodeBusTopologyMarker
impl Ord for NodeBusTopologyMarker
Sourcefn cmp(&self, other: &NodeBusTopologyMarker) -> Ordering
fn cmp(&self, other: &NodeBusTopologyMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NodeBusTopologyMarker
impl PartialEq for NodeBusTopologyMarker
Sourceimpl PartialOrd for NodeBusTopologyMarker
impl PartialOrd for NodeBusTopologyMarker
Sourceimpl ProtocolMarker for NodeBusTopologyMarker
impl ProtocolMarker for NodeBusTopologyMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.driver.token.NodeBusTopology"
const DEBUG_NAME: &'static str = "fuchsia.driver.token.NodeBusTopology"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = NodeBusTopologyProxy
type Proxy = NodeBusTopologyProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = NodeBusTopologyRequestStream
type RequestStream = NodeBusTopologyRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = NodeBusTopologySynchronousProxy
type SynchronousProxy = NodeBusTopologySynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for NodeBusTopologyMarker
impl Eq for NodeBusTopologyMarker
impl StructuralPartialEq for NodeBusTopologyMarker