pub struct NodeTokenMarker;Trait Implementations
Sourceimpl Clone for NodeTokenMarker
impl Clone for NodeTokenMarker
Sourcefn clone(&self) -> NodeTokenMarker
fn clone(&self) -> NodeTokenMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeTokenMarker
impl Debug for NodeTokenMarker
Sourceimpl Hash for NodeTokenMarker
impl Hash for NodeTokenMarker
Sourceimpl Ord for NodeTokenMarker
impl Ord for NodeTokenMarker
Sourcefn cmp(&self, other: &NodeTokenMarker) -> Ordering
fn cmp(&self, other: &NodeTokenMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NodeTokenMarker
impl PartialEq for NodeTokenMarker
Sourceimpl PartialOrd for NodeTokenMarker
impl PartialOrd for NodeTokenMarker
Sourceimpl ProtocolMarker for NodeTokenMarker
impl ProtocolMarker for NodeTokenMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) NodeToken"
const DEBUG_NAME: &'static str = "(anonymous) NodeToken"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = NodeTokenProxy
type Proxy = NodeTokenProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = NodeTokenRequestStream
type RequestStream = NodeTokenRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = NodeTokenSynchronousProxy
type SynchronousProxy = NodeTokenSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for NodeTokenMarker
impl Eq for NodeTokenMarker
impl StructuralPartialEq for NodeTokenMarker