pub enum NodeTokenRequest {
Get {
responder: NodeTokenGetResponder,
},
}Expand description
A protocol that is meant to be composed into other protocols to allow driver
clients to query the node token associated with the driver. This token can be
exchanged with the driver framework via protocols such as
fuchsia.driver.token/NodeBusTopology.Get to learn more information about the
node.
Variants
Get
Fields

responder: NodeTokenGetResponderImplementations
Sourceimpl NodeTokenRequest
impl NodeTokenRequest
pub fn into_get(self) -> Option<NodeTokenGetResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL